#!/usr/bin/env python
"""Wetland processing op for ArcGIS 10 schematic processor tool."""

from decimal import Decimal

import schematic_exceptions as ex

def process_values(row, input_values):
    """Simulates 50% removal of constituents via magical wetland.

    Arguments:
        row -- input row representing schematic feature
        input_values -- list of ValueTuple objects
    Remarks:
        ValueTuple objects have these attributes:
        value -- numerical value to process
        source_class -- class containing the feature providing the value
        feature_id -- unique identifier of the feature providing
                      the value

        This function only processes the first value found.
                          
    """

    # Validate inputs
    validate_inputs(input_values)

    # Get parameters from input row
    v = input_values[0]
    input_value = Decimal(str(v.value))

    result = input_value * Decimal('0.5')

    return result

def validate_inputs(input_values):
    """Checks values for valid inputs.

    Arguments:
        input_values -- list of ValueTuple objects

    """

    # Only one ValueTuple present
    if len(input_values) != 1:
        msg = "Wetland op can only take one value as input.  " + \
              "Values provided: " + str(len(input_values)) + ".  " + \
              "Please make sure this op is used only for PASS behavior."
        raise ex.OpError(msg)
